.. _Publications:

Publications
============
Papers:

* Castillo-Reyes, O., de la Puente, J., García-Castillo, L. E., Cela, J.M. (2019). `Parallel 3-D marine controlled-source electromagnetic modelling using high-order tetrahedral Nédélec elements <https://doi.org/10.1093/gji/ggz285>`_. Geophysical Journal International, Volume 219, Issue 1, October 2019, Pages 39–65.
* Castillo-Reyes, O., de la Puente, Cela, J. M. `PETGEM: A parallel code for 3D CSEM forward modeling using edge finite elements <https://doi.org/10.1016/j.cageo.2018.07.005>`_. Computers & Geosciences, vol 119: 123-136. ISSN 0098-3004. Elsevier.
* Castillo-Reyes, O., de la Puente, Cela, J. M. `Three-Dimensional CSEM modelling on unstructured tetrahedral meshes using edge finite elements <https://link.springer.com/chapter/10.1007/978-3-319-57972-6_18>`_. In: Barrios Hernández C., Gitler I., Klapp J. (eds) High Performance Computing. CARLA 2016. Communications in Computer and Information Science, vol 697: 247-256. ISBN 978-3-319-57971-9 Springer, Cham. 2017.
* Castillo-Reyes, O., de la Puente, Cela, J. M. `Improving edge finite element assembly for geophysical electromagnetic modelling on shared-memory architectures <https://doi.org/10.1109/UEMCON.2016.7777804>`_. 7th Annual Ubiquitous Computing, Electronics & Mobile Communication Conference – UEMCON. 2016.
* Castillo-Reyes, O., de la Puente, J., Puzyrev, V., and Cela, J. M., `Edge-based parallel framework for the simulation of 3D CSEM surveys <http://www.bsc.es/publications/edge-based-parallel-framework-simulation-3d-csem-surveys>`_. ICE Barcelona-AAPG/SEG International Conference & Exhibition. 2016.
* Castillo-Reyes, O., de la Puente, J., Barucq, H., Diaz, J., and Cela, J. M., `Parallel and vectorized code for CSEM surveys in geophysics: An edge-based approach <http://www.bsc.es/publications/parallel-and-vectorized-code-csem-surveys-geophysics-edge-based-approach>`_. ECCOMAS. 2016.
* Castillo-Reyes, O., de la Puente, J., Modesto, D., Puzyrev, V., and Cela, J. M., `A parallel tool for numerical approximation of 3D electromagnetic surveys in geophysics <http://www.bsc.es/publications/parallel-tool-numerical-approximation-3d-electromagnetic-surveys-geophysics>`_. Computación y Sistemas: Topic trends in computing research, vol. 20, no. 1, pp 29-39. 2016.
* Castillo-Reyes, O., de la Puente, J., Puzyrev, V., and Cela, J. M., `Towards an HPC tool for simulation of 3D CSEM surveys: an edge-based approach <http://www.bsc.es/publications/towards-hpc-tool-simulation-3d-csem-surveys-edge-based-approach>`_. PRACEdays16 Conference. 2016.
* Castillo-Reyes, O., de la Puente, J., Puzyrev, V., and Cela, J. M., `Assessment of edge-based finite element technique for geophysical electromagnetic problems: efficiency, accuracy and reliability <http://www.bsc.es/publications/assessment-edge-based-finite-element-technique-geophysical-electromagnetic-problems>`_. Proceedings of the 1st Pan-American Congress on Computational Mechanics and XI Argentine Congress on Computational Mechanics. CIMNE, pp. 984-995, 2015.
* Castillo-Reyes, O., de la Puente, J., Puzyrev, V., and Cela, J. M., `Edge-based electric field formulation in 3D CSEM simulations: a parallel approach <http://dx.doi.org/10.1109/IEMCON.2015.7344499>`_. Proceedings of the 6th International Conference and Workshop on Computing and Communication. IEEE, 2015.
* Castillo-Reyes, O., de la Puente, J., Puzyrev, V., and Cela, J. M., `Edge-elements for geophysical electromagnetic problems: a new implementation challenge <http://www.bsc.es/publications/edge-elements-geophysical-electromagnetic-problems-new-implementation-challenge>`_. PRACEdays15 Conference. 2015.
* Castillo-Reyes, O., de la Puente, J., Puzyrev, V., and Cela, J. M., `HPC and edge elements for geophysical electromagnetic problems: an overview <http://www.bsc.es/publications/hpc-and-edge-elements-geophysical-electromagnetic-problems-overview>`_. BSC Doctoral Symposium (2nd: 2015: Barcelona). 2015.
* Castillo-Reyes, O., de la Puente, J., Puzyrev, V., and Cela, J. M., `Parallel and numerical issues of the edge finite element method for 3D controlled-source electromagnetic surveys <http://dx.doi.org/10.1109/ICCSAT.2015.7362921>`_. Proceedings of the International Conference on Computing Systems and Telematics. IEEE, 2015.

Conferences:

* Castillo-Reyes, O. HPC geophysical electromagnetic modeling. Fifth International Congress on Multiphysics, Multiscale, and Optimization problems. University of the Basque Country. Bilbao, Spain. May 2018.
* Castillo-Reyes, O. Python performance for HPC geophysical applications. 9th International Supercomputing Conference in Mexico – ISUM 2018. Red Mexicana de Supercómputo. Mérida, Yucatán, Mexico. March 2018.
* Castillo-Reyes, O. Overview of numerical techniques and applications for CSEM/MT geophysical surveys. SIAM Conference on Mathematical and Computational Issues in the Geosciences. University Erlangen-Nürnberg. Erlangen, Germany. September 2017.
* Castillo-Reyes, O. PETGEM: Parallel Edge-based Tool for Geophysical Electromagnetic Modelling. Congress on Numerical Methods in Engineering. Technical University of Valencia. Valencia, Spain. July 2017.
* Castillo-Reyes, O. PETGEM: potential of 3D CSEM modelling using a new HPC tool for exploration geophysics. 10th International Marine Electromagnetics conference – MARELEC. University of Liverpool. Liverpool, United Kingdom. June 2017.
* Castillo-Reyes, O. High performance computing using python: advances in geophysical electromagnetic modelling. Computing and Electromagnetics International Workshop. Polytechnic University of Catalonia. Barcelona, Spain. June 2017.
* Castillo-Reyes, O. Python code for CSEM modelling in geophysics and HPC architectures: advances and challenges. 2do Foro Internacional de Talento Mexicano – Innovation Match MX 2016-2017. Mexico, D.F. May 2017.
* Castillo-Reyes, O. Python for HPC geophysical applications. GeoPython 2017. University of Applied Sciences and Arts Northwestern Switzerland. Basel, Switzerland. May 2017.
* Castillo-Reyes, O. Python for HPC geophysical electromagnetic applications: experiences and perspectives. 4th BSC International Doctoral Symposium. Barcelona, Spain. May 2017.
* Castillo-Reyes, O. See underneath. High Performance Computing, geophysics and electromagnetic methods. Interdisciplinary Meeting of Predoctoral Researchers – JIPI 2017. University of Barcelona. Barcelona, Spain. February 2017.
* Castillo-Reyes, O. Supercomputing and electromagnetic modelling in geophysics: advances and challenges. Centro de Ciencias de la tierra. University of Veracruz. Xalapa, Veracruz, Mexico. December 2016.
* Castillo-Reyes, O. Improving edge finite element assembly for geophysical electromagnetic modelling on shared-memory architectures. 7th IEEE Annual Ubiquitous Computing, Electronics & Mobile Communication Conference – UEMCON 2016. New York, USA. October 2016.
* Castillo-Reyes, O. Three-dimensional CSEM modelling on unstructured tetrahedral meshes using edge finite elements. Latin American High Performance Computing Conference – CARLA 2016.  Mexico, D.F. August 2016.
* Castillo-Reyes, O. Edge-based parallel code for CSEM surveys in geophysics: performance and accuracy improvements. 12th World Congress on Computational Mechanics – WCCM XII. Seúl, Corea. July 2016.
* Castillo-Reyes, O. Towards an HPC tool for 3D CSEM forward modelling in geophysics. Fourth International Congress on Multiphysics, Multiscale, and Optimization problems. Bilbao, España. May 2016
* Castillo-Reyes, O. High performance computing, geophysics and numerical methods: a symbiotic relation. 1er Foro Internacional de Talento Mexicano – Innovation Match MX 2015-2016. Guadalajara, Jalisco, México. April 2016.
* Castillo-Reyes, O. Edge-based electric field formulation in 3D CSEM simulations: a parallel approach. 6th International Conference and Workshop on Computing and Communication – IEMCON – 2015. University of British Columbia. Vancouver, Canada. October 2015.
* Castillo-Reyes, O. High Performance Computing and electromagnetic modeling in geophysics: from concepts to application. Research Center in Computing. National Polytechnic Institute. Mexico, D.F. October 2015.
* Castillo-Reyes, O. Parallel and numerical issues of the edge finite element method for 3D controlled-source electromagnetic surveys. IEEE International Conference on Computing Systems and Telematics. University of Veracruz. Xalapa, Veracruz, Mexico. October 2015.
* Castillo-Reyes, O. "Your Thesis in 3 Minutes” (3TM) with the topic: Edge-elements formulation of CSEM in geophysics: a parallel approach. Jornadas de Cooperación CONACyT – Cataluña 2015. Polytechnic University of Catalonia – National Council of Science and Technology of Mexico. Barcelona, Spain. June 2015.
* Castillo-Reyes, O. Edge-elements for geophysical electromagnetic problems: A new implementation challenge. PRACE Scientific and Industrial Conference 2015 – PRACEDays15. Dublin, Ireland. April 2015.
* Castillo-Reyes, O. HPC and edge elements for geophysical electromagnetic problems: an overview. 2nd BSC International Doctoral Symposium. Barcelona, Spain. April 2015.
* Castillo-Reyes, O. Assessment of edge-based finite element technique for geophysical electromagnetic problems: efficiency, accuracy and reliability. 1st. Pan-American Congress on Computational Mechanics – PANACM 2015. IACM. Buenos Aires, Argentina. April 2015.
* Castillo-Reyes, O. HPC solutions for oil industry: trends and challenges. Centro de Ciencias de la Tierra. University of Veracruz. Xalapa, Veracruz, Mexico. December 2014.
* Castillo-Reyes, O. High Performance Computing, Science and Engineering. Master in Telematic. School of Accounting and Management. University of Veracruz. Xalapa, Veracruz, Mexico. December 2014.
* Castillo-Reyes, O. HPC solutions for oil industry: trends and challenges. IV Simposio de Becarios CONACyT en Europa. Strasbourg, France. November 2014.

Support
=======
Work on PETGEM has received funding from the European Union's Horizon 2020 research and innovation programme under
the Marie Sklodowska-Curie grant agreement No. 644202. The research leading to these results has received funding
from the European Union's Horizon 2020 Programme (2014-2020) and from Brazilian Ministry of Science, Technology and
Innovation through Rede Nacional de Pesquisa (RNP) under the `HPC4E Project <http://www.hpc4e.eu>`_ , grant agreement
No. 689772. Further, this project has received funding from the European Union's Horizon 2020 research and innovation
programme under the Marie Sklodowska-Curie grant agreement No. 777778. Moreover, the development of PETGEM has received
funding from the European Union’s Horizon 2020 programme, grant agreement N◦828947, and from the Mexican Department of
Energy, CONACYT-SENER Hidrocarburos grant agreement N◦B-S-69926. Finally, this project has been 65% cofinanced by the
European Regional Development Fund (ERDF) through the Interreg V-A Spain-France-Andorra program
(POCTEFA2014-2020). POCTEFA aims to reinforce the economic and social integration of the French-Spanish-Andorran
border. Its support is focused on developing economic, social and environmental cross-border activities through joint
strategies favouring sustainable territorial development

Octavio Castillo-Reyes expresses his gratitude to the Mexican National Council for Science and Technology (`CONACyT <http://www.conacyt.mx/>`_) for his support.
